"""
DO NOT EDIT - Run scripts/generate_valid_slash_commands.py to regenerate

Generated: 2025-12-22 07:35:52 UTC
"""

VALID_SLASH_COMMANDS: dict[str, str] = {
    "": "",
    "ac": "ac",
    "afk": "afk",
    "ah": "ah",
    "ai": "ai",
    "alt2tray": "alt2tray",
    "altinvite": "altinvite",
    "alttray": "alttray",
    "alttraysticky": "alttraysticky",
    "anglesnap": "anglesnap",
    "anglesnapcycle": "anglesnapcycle",
    "antialiasing": "fsaa",
    "architect": "architect",
    "architectclaimtickets": "architectclaimtickets",
    "architectcompletemission": "architectcompletemission",
    "architectexit": "architectexit",
    "architectfixerrors": "architectfixerrors",
    "architectinvincible": "architectinvincible",
    "architectinvisible": "architectinvisible",
    "architectkilltarget": "architectkilltarget",
    "architectloginupdate": "architectloginupdate",
    "architectnextcritter": "architectnextcritter",
    "architectnextobjective": "architectnextobjective",
    "architectrepublish": "architectrepublish",
    "architectsaveandexit": "architectsaveandexit",
    "architectsaveandtest": "architectsaveandtest",
    "architectsavecompressedcostumes": "architectsavecompressedcostumes",
    "arena": "ac",
    "arenainvite": "ai",
    "arenalist": "arenalist",
    "arenalocal": "arenalocal",
    "arenascore": "arenascore",
    "assist": "assist",
    "assistname": "assistname",
    "attachcycle": "attachcycle",
    "aucloginupdate": "aucloginupdate",
    "auction": "auction",
    "auctionhouse": "ah",
    "autoreply": "autoreply",
    "autorun": "autorun",
    "b": "b",
    "backward": "backward",
    "badgegrant": "badgegrant",
    "basedefaultsky": "basedefaultsky",
    "baselightingtype": "baselightingtype",
    "baseredo": "baseredo",
    "baseselect": "baseselect",
    "baseundo": "baseundo",
    "beginchat": "beginchat",
    "bind": "bind",
    "bindload": "bindload",
    "bindloadfile": "bindloadfile",
    "bindloadfilesilent": "bindloadfilesilent",
    "bindsave": "bindsave",
    "bindsavefile": "bindsavefile",
    "bindsavefilesilent": "bindsavefilesilent",
    "blackmarket": "ah",
    "bloomscale": "bloomscale",
    "bloomweight": "bloomweight",
    "boostconvert": "boostconvert",
    "broadcast": "b",
    "buildsave": "buildsave",
    "buildsavefile": "buildsavefile",
    "c": "c",
    "camdist": "camdist",
    "camdistadjust": "camdistadjust",
    "camreset": "camreset",
    "camrotate": "camrotate",
    "camturn": "camturn",
    "canlook": "canlook",
    "cc": "cc",
    "cce": "cce",
    "ccemote": "cce",
    "center": "center",
    "centersel": "centersel",
    "chancreate": "chancreate",
    "chandesc": "chandesc",
    "changehandle": "changehandle",
    "chaninvite": "ginvite",
    "chaninvitedeny": "chaninvitedeny",
    "chaninvitegf": "chaninvitegf",
    "chaninvitesg": "ginvitesg",
    "chaninviteteam": "chaninviteteam",
    "chanjoin": "chanjoin",
    "chanleave": "chanleave",
    "chanmembers": "chanmembers",
    "chanmode": "chanmode",
    "chanmotd": "chanmotd",
    "chansend": "send",
    "chantimeout": "chantimeout",
    "chanusermode": "chanusermode",
    "chat": "chat",
    "chatcycle": "chatcycle",
    "chatload": "chatload",
    "chatloadfile": "chatloadfile",
    "chatoptions": "chatoptions",
    "chatsave": "chatsave",
    "chatsavefile": "chatsavefile",
    "chatset": "chatset",
    "ci": "ci",
    "citytime": "citytime",
    "clearattributeview": "clearattributeview",
    "clearchat": "clearchat",
    "clearpetnames": "clearpetnames",
    "clearrewardchoice": "clearrewardchoice",
    "cleartray": "cleartray",
    "clicktomove": "ctm",
    "cmdlist": "cmdlist",
    "coalition": "c",
    "coalitioncancel": "coalitioncancel",
    "coalitioninvite": "ci",
    "coalitionmintalkrank": "coalitionmintalkrank",
    "coalitionnosend": "coalitionnosend",
    "coalitionsgmintalkrank": "coalitionsgmintalkrank",
    "comment": "comment",
    "compatiblecursors": "compatiblecursors",
    "conprint": "conprint",
    "contactfinderselectcurrent": "contactfinderselectcurrent",
    "contactfindershowcurrent": "contactfindershowcurrent",
    "contactfindershownext": "contactfindershownext",
    "contactfindershowprevious": "contactfindershowprevious",
    "contactfinderteleporttocurrent": "contactfinderteleporttocurrent",
    "contextmenu": "contextmenu",
    "controllermodifiers": "controllermodifiers",
    "controllervmouse": "controllervmouse",
    "cooldownindicator": "cooldownindicator",
    "copychat": "copychat",
    "costumechange": "cc",
    "ctm": "ctm",
    "ctminvert": "ctm",
    "ctmtoggle": "ctmtoggle",
    "cursorcache": "cursorcache",
    "customwindow": "customwindow",
    "customwindowtoggle": "customwindowtoggle",
    "debugdisableautodismiss": "debugdisableautodismiss",
    "demodump": "demodump",
    "demodumptga": "demodumptga",
    "demofps": "demofps",
    "demoframestats": "demoframestats",
    "demohideallentityui": "demohideallentityui",
    "demohidechat": "demohidechat",
    "demohidedamage": "demohidedamage",
    "demohidenames": "demohidenames",
    "demoloop": "demoloop",
    "demopause": "demopause",
    "demorecord": "demorecord",
    "demorecordauto": "demorecordauto",
    "demospeedscale": "demospeedscale",
    "demostop": "demostop",
    "demote": "demote",
    "dialoganswer": "dialoganswer",
    "dialogno": "dialogno",
    "dialogyes": "dialogyes",
    "disable2d": "disable2d",
    "dofweight": "dofweight",
    "down": "down",
    "e": "e",
    "editbase": "editbase",
    "em": "e",
    "emailheaders": "emailheaders",
    "emote": "e",
    "enablevbos": "enablevbos",
    "enterbasefrompasscode": "enterbasefrompasscode",
    "enterbasefromsgid": "enterbasefromsgid",
    "enterdoor": "enterdoor",
    "estrange": "estrange",
    "exitlaunch": "exitlaunch",
    "extramodifiers": "extramodifiers",
    "f": "f",
    "face": "face",
    "findmember": "sea",
    "first": "first",
    "fl": "fl",
    "follow": "follow",
    "forward": "forward",
    "forwardmouse": "forwardmouse",
    "friend": "friend",
    "friendlist": "fl",
    "fsaa": "fsaa",
    "fullrelight": "fullrelight",
    "fullscreen": "fullscreen",
    "g": "g",
    "gamereturn": "gamereturn",
    "gen": "z",
    "general": "z",
    "getallarenastats": "getallarenastats",
    "getarenastats": "getarenastats",
    "getcomment": "comment",
    "getglobalname": "getglobalname",
    "getlocalinvite": "getlocalinvite",
    "getlocalleagueinvite": "getlocalleagueinvite",
    "getlocalname": "getlocalname",
    "getpos": "loc",
    "getratedarenastats": "getarenastats",
    "gfriend": "gfriend",
    "gfriends": "gfriends",
    "ghide": "hide",
    "gignore": "ignore",
    "gignoring": "gignoring",
    "ginvite": "ginvite",
    "ginvitesg": "ginvitesg",
    "gmotd": "gmotd",
    "gototray": "gototray",
    "gototrayalt": "gototrayalt",
    "gototrayalt2": "gototrayalt2",
    "gototraystray": "gototraystray",
    "graphfps": "graphfps",
    "gridsnap": "gridsnap",
    "gridsnapcycle": "gridsnapcycle",
    "group": "g",
    "guide": "h",
    "gunfriend": "gunfriend",
    "gunfriendplayer": "gunfriend",
    "gunhide": "hide",
    "gunignore": "unignore",
    "h": "h",
    "hardconsts": "hardconsts",
    "hc": "h",
    "help": "h",
    "helpchat": "h",
    "helpwindow": "helpwindow",
    "hide": "hide",
    "hideall": "hideall",
    "hidefriends": "hidefriends",
    "hidegchannels": "hidegchannels",
    "hidegfriends": "hidegfriends",
    "hideinvite": "hideinvite",
    "hideprimarychat": "hideprimarychat",
    "hidesearch": "hidesearch",
    "hideset": "hideset",
    "hidesg": "hidesg",
    "hidetell": "hidetell",
    "i": "i",
    "ignore": "ignore",
    "ignorelist": "gignoring",
    "ignorespammer": "ignorespammer",
    "imageserver": "imageserver",
    "incarnateequip": "incarnateequip",
    "incarnateunequip": "incarnateunequip",
    "incarnateunequipall": "incarnateunequipall",
    "incarnateunequipbyslot": "incarnateunequipbyslot",
    "info": "info",
    "infopinbadge": "infopinbadge",
    "infoself": "infoself",
    "infoselftab": "infoselftab",
    "infotab": "infotab",
    "inspcombine": "mergeinsp",
    "inspdelete": "inspdelete",
    "inspexecname": "inspexecname",
    "inspexecpetname": "inspexecpetname",
    "inspexecpettarget": "inspexecpettarget",
    "inspexecslot": "inspexecslot",
    "inspexectray": "inspexectray",
    "inspirationslot": "inspexecslot",
    "interact": "interact",
    "invite": "invite",
    "k": "k",
    "keybindreset": "unbindall",
    "kick": "k",
    "kiosk": "kiosk",
    "l": "l",
    "lc": "lc",
    "league": "lc",
    "leaguechat": "lc",
    "leagueinvite": "li",
    "leaguekick": "lk",
    "leaguemakeleader": "lml",
    "leaguetoggleteamlock": "leaguetoggleteamlock",
    "leaguewithdrawteam": "leaguewithdrawteam",
    "leaveleague": "leaveleague",
    "leaveteam": "leaveteam",
    "left": "left",
    "lfg": "lfg",
    "lfgeventresponse": "lfgeventresponse",
    "lfgremovefromqueue": "lfgremovefromqueue",
    "lfgrequesteventlist": "lfgrequesteventlist",
    "lfgset": "lfgset",
    "lfgtoggle": "lfgtoggle",
    "li": "li",
    "linkchannel": "linkchannel",
    "linkinfo": "linkinfo",
    "linkinteract": "linkinteract",
    "linkinteractglobal": "linkinteractglobal",
    "listenrange": "listenrange",
    "lk": "lk",
    "lml": "lml",
    "loc": "loc",
    "local": "l",
    "localtime": "localtime",
    "lodbias": "lodbias",
    "logchat": "logchat",
    "lookdown": "lookdown",
    "lookingforgroup": "lfg",
    "lookup": "lookup",
    "loudstacking": "loudstacking",
    "ma": "ma",
    "macro": "macro",
    "macroimage": "macroimage",
    "macroslot": "macroslot",
    "mailview": "mailview",
    "makeleader": "ml",
    "manage": "manage",
    "map": "map",
    "maxaniso": "maxaniso",
    "maxcolortrackerverts": "maxcolortrackerverts",
    "maxfps": "maxfps",
    "maximize": "maximize",
    "maxinactivefps": "maxinactivefps",
    "maxrtframes": "maxrtframes",
    "maxtexunits": "maxtexunits",
    "me": "e",
    "menu": "menu",
    "mergeinsp": "mergeinsp",
    "missionarchitect": "ma",
    "missionmake": "mmentry",
    "missionsearch": "architect",
    "ml": "ml",
    "mmentry": "mmentry",
    "mmscrollsettoggleregion": "mmscrollsettoggleregion",
    "mmscrollsetviewlist": "mmscrollsetviewlist",
    "monitorattribute": "monitorattribute",
    "mousedrag": "mousedrag",
    "mouseinvert": "mouseinvert",
    "mouselook": "canlook",
    "mousespeed": "mousespeed",
    "myhandle": "myhandle",
    "mypurchases": "mypurchases",
    "namecaptain": "namecaptain",
    "namecommander": "namecommander",
    "nameenforcer": "nameenforcer",
    "nameflunky": "nameflunky",
    "nameleader": "nameleader",
    "namelieutenant": "namelieutenant",
    "namemember": "namemember",
    "nameoverlord": "nameoverlord",
    "nameringleader": "nameringleader",
    "namescale": "namescale",
    "nametaskmaster": "nametaskmaster",
    "nav": "nav",
    "neterrorcorrection": "neterrorcorrection",
    "netgraph": "netgraph",
    "nexttray": "nexttray",
    "nexttrayalt": "nexttrayalt",
    "nexttrayalt2": "nexttrayalt2",
    "nexttraystray": "nexttraystray",
    "nobump": "nobump",
    "nojpg": "nojpg",
    "nojumprepeat": "nojumprepeat",
    "nop": "nop",
    "noparticles": "noparticles",
    "nosunflare": "nosunflare",
    "notga": "notga",
    "optionlist": "optionlist",
    "optionload": "optionload",
    "optionloadfile": "optionloadfile",
    "optionsave": "optionsave",
    "optionsavefile": "optionsavefile",
    "optionset": "optionset",
    "optiontoggle": "optiontoggle",
    "p": "p",
    "petcom": "petcom",
    "petcomall": "petcomall",
    "petcomname": "petcomname",
    "petcompow": "petcompow",
    "petition": "petition",
    "petoptions": "petoptions",
    "petrename": "petrename",
    "petrenamename": "petrenamename",
    "petsay": "petsay",
    "petsayall": "petsayall",
    "petsayname": "petsayname",
    "petsaypow": "petsaypow",
    "petselect": "petselect",
    "petselectname": "petselectname",
    "playernote": "playernote",
    "playernotelocal": "playernotelocal",
    "playerturn": "playerturn",
    "popmenu": "popmenu",
    "powers": "powers",
    "powerstogglealloff": "powerstogglealloff",
    "powexecabort": "powexecabort",
    "powexecalt2slot": "powexecalt2slot",
    "powexecaltslot": "powexecaltslot",
    "powexecauto": "powexecauto",
    "powexeclocation": "powexeclocation",
    "powexecname": "powexecname",
    "powexecserverslot": "powexecserverslot",
    "powexecslot": "powexecslot",
    "powexectoggleoff": "powexectoggleoff",
    "powexectoggleon": "powexectoggleon",
    "powexectray": "powexectray",
    "powexecunqueue": "powexecunqueue",
    "prevshaders": "prevshaders",
    "prevtray": "prevtray",
    "prevtrayalt": "prevtrayalt",
    "prevtrayalt2": "prevtrayalt2",
    "prevtraystray": "prevtraystray",
    "private": "t",
    "profilerrecord": "profilerrecord",
    "profilerstop": "profilerstop",
    "profilingmemory": "profilingmemory",
    "promote": "promote",
    "quickchat": "quickchat",
    "quit": "quit",
    "quittocharacterselect": "quittocharacterselect",
    "quittologin": "quittologin",
    "r": "r",
    "rechargeindicator": "rechargeindicator",
    "rechargetimercolor": "rechargetimercolor",
    "rechargetimerformat": "rechargetimerformat",
    "rechargetimeropacity": "rechargetimeropacity",
    "rechargetimerthreshold": "rechargetimerthreshold",
    "reducemip": "reducemip",
    "release": "release",
    "releasepets": "releasepets",
    "reloadgfx": "reloadgfx",
    "renderscale": "renderscale",
    "renderscalex": "renderscalex",
    "renderscaley": "renderscaley",
    "rendersize": "rendersize",
    "reply": "r",
    "req": "req",
    "request": "request",
    "requestexitmission": "requestexitmission",
    "respec": "respec",
    "respecstatus": "respecstatus",
    "right": "right",
    "roleplaying": "roleplaying",
    "roll": "roll",
    "roomclip": "roomclip",
    "roomclipcycle": "roomclipcycle",
    "rotate": "rotate",
    "s": "s",
    "salvageopen": "salvageopen",
    "say": "s",
    "screen": "screen",
    "screenshot": "screenshot",
    "screenshottga": "screenshottga",
    "screenshottitle": "screenshottitle",
    "screenshotui": "screenshotui",
    "sea": "sea",
    "search": "sea",
    "seeeverything": "seeeverything",
    "selectbuild": "selectbuild",
    "selectlast": "selectlast",
    "selectnext": "selectnext",
    "sell": "sell",
    "send": "send",
    "servertime": "servertime",
    "setdifficultyav": "setdifficultyav",
    "setdifficultyboss": "setdifficultyboss",
    "setdifficultylevel": "setdifficultylevel",
    "setdifficultyteamsize": "setdifficultyteamsize",
    "sethelperstatus": "sethelperstatus",
    "setpowerinfoclass": "setpowerinfoclass",
    "settitle": "settitle",
    "settitleid": "settitle",
    "sg": "sg",
    "sgenterpasscode": "sgenterpasscode",
    "sgi": "sgi",
    "sginvite": "sgi",
    "sgk": "sgk",
    "sgkick": "sgk",
    "sgkickyes": "sgkickyes",
    "sgleave": "sgleave",
    "sgmode": "sgmode",
    "sgmodeset": "sgmodeset",
    "sgmusic": "sgmusic",
    "sgpasscode": "sgpasscode",
    "sgsetdemotetimeout": "sgsetdemotetimeout",
    "sgsetdescription": "sgsetdescription",
    "sgsetmotd": "sgsetmotd",
    "sgsetmotto": "sgsetmotto",
    "sgwho": "sgwho",
    "shadercache": "shadercache",
    "sheathe": "sheathe",
    "show": "show",
    "showbind": "showbind",
    "showbindall": "showbindall",
    "showbindallfile": "showbindallfile",
    "showfps": "showfps",
    "shownewtray": "shownewtray",
    "showpetnames": "showpetnames",
    "showtime": "showtime",
    "slashchat": "slashchat",
    "speakrange": "speakrange",
    "speedturn": "speedturn",
    "startchat": "startchat",
    "stopinactivedisplay": "stopinactivedisplay",
    "stopmonitorattribute": "stopmonitorattribute",
    "stuck": "stuck",
    "supergroup": "sg",
    "supporthardwarelights": "supporthardwarelights",
    "suppressclosefx": "suppressclosefx",
    "suppressclosefxdist": "suppressclosefxdist",
    "sync": "sync",
    "synch": "sync",
    "t": "t",
    "tabclose": "tabclose",
    "tabcreate": "tabcreate",
    "tabglobalnext": "tabglobalnext",
    "tabglobalprev": "tabglobalprev",
    "tabnext": "tabnext",
    "tabprev": "tabprev",
    "tabselect": "tabselect",
    "tabtoggle": "tabtoggle",
    "tailorstatus": "tailorstatus",
    "target": "target",
    "targetcustomfar": "targetcustomfar",
    "targetcustomnear": "targetcustomnear",
    "targetcustomnext": "targetcustomnext",
    "targetcustomprev": "targetcustomprev",
    "targetdistance": "targetdistance",
    "targetenemyfar": "targetenemyfar",
    "targetenemynear": "targetenemynear",
    "targetenemynext": "toggleenemy",
    "targetenemyprev": "targetenemyprev",
    "targetfriendfar": "targetfriendfar",
    "targetfriendnear": "targetfriendnear",
    "targetfriendnext": "targetfriendnext",
    "targetfriendprev": "targetfriendprev",
    "targetname": "targetname",
    "team": "g",
    "teammovetoleague": "teammovetoleague",
    "teamquitinternal": "teamquitinternal",
    "teamselect": "teamselect",
    "tell": "t",
    "telllast": "tl",
    "texaniso": "texaniso",
    "texlodbias": "texlodbias",
    "third": "third",
    "thumbtack": "thumbtack",
    "titlechange": "titlechange",
    "tl": "tl",
    "tll": "tll",
    "tmtl": "tmtl",
    "toggle": "toggle",
    "toggleenemy": "toggleenemy",
    "toggleenemyprev": "toggleenemyprev",
    "trade": "trade",
    "tradeaccept": "tradeaccept",
    "tray": "tray",
    "trayalwaysshrink": "trayalwaysshrink",
    "trayanimations": "trayanimations",
    "traylabels": "traylabels",
    "traysticky": "traysticky",
    "traystickyalt2": "traystickyalt2",
    "ttl": "ttl",
    "turnleft": "turnleft",
    "turnright": "turnright",
    "tutvotekick": "tutvotekick",
    "tutvotekickopinion": "tutvotekickopinion",
    "uiscale": "uiscale",
    "unbind": "unbind",
    "unbindall": "unbindall",
    "unfriend": "unfriend",
    "unhide": "hide",
    "unhideall": "unhideall",
    "unhidefriends": "unhidefriends",
    "unhidegchannels": "unhidegchannels",
    "unhidegfriends": "unhidegfriends",
    "unhideinvite": "unhideinvite",
    "unhidesearch": "unhidesearch",
    "unhidesg": "unhidesg",
    "unhidetell": "unhidetell",
    "unignore": "unignore",
    "unlevelingpact": "unlevelingpact",
    "unloadgfx": "unloadgfx",
    "unselect": "unselect",
    "up": "up",
    "usecelshader": "usecelshader",
    "usecubemap": "usecubemap",
    "usedof": "usedof",
    "usefp": "usefp",
    "usehdr": "usehdr",
    "usehq": "usehq",
    "userenderscale": "userenderscale",
    "usewater": "usewater",
    "visscale": "visscale",
    "watching": "watching",
    "wdwload": "wdwload",
    "wdwloadfile": "wdwloadfile",
    "wdwsave": "wdwsave",
    "wdwsavefile": "wdwsavefile",
    "wentworths": "ah",
    "whereami": "whereami",
    "whisper": "t",
    "who": "who",
    "whoall": "whoall",
    "windowcloseextra": "gamereturn",
    "windowcolor": "windowcolor",
    "windowhide": "windowhide",
    "windownames": "windownames",
    "windowresetall": "windowresetall",
    "windowscale": "windowscale",
    "windowshow": "show",
    "windowtoggle": "toggle",
    "y": "y",
    "yell": "b",
    "z": "z",
    "zoomin": "zoomin",
    "zoomout": "zoomout",
}
