class TemplateConstants:
    ENCAPSULATION_PATTERN = "<>"
    ENCAPSULATION_LEFT = ENCAPSULATION_PATTERN[: len(ENCAPSULATION_PATTERN) // 2]
    ENCAPSULATION_RIGHT = ENCAPSULATION_PATTERN[len(ENCAPSULATION_PATTERN) // 2 :]
