class CommonSlashCommands:

    # Power execution commands
    POWEXEC_NAME = "powexecname"
    POWEXEC_TOGGLE_OFF = "powexectoggleoff"
    POWEXEC_TOGGLE_ON = "powexectoggleon"
    POWEXEC_AUTO = "powexecauto"
    POWEXEC_LOCATION = "powexeclocation"

    # Bind file commands
    BIND_LOAD = "bindload"
    BIND_LOAD_FILE = "bindloadfile"
    BIND_LOAD_FILE_SILENT = "bindloadfilesilent"
    BIND_SAVE = "bindsave"  # TODO: verify if these commands still work. Should be show_bind_file? (2025/11/28)
    BIND_SAVE_FILE = "bindsavefile"
    BIND_SAVE_FILE_SILENT = "bindsavefilesilent"

    # Emote commands
    EMOTE = "e"

    # Costume change commands
    CC = "cc"
    CC_EMOTE = "cce"

    # Chat commands
    CHAT_SAY = "s"
    CHAT_LOCAL = "l"
    CHAT_BROADCAST = "b"
    CHAT_LFG = "lfg"
    CHAT_TEAM = "g"
    CHAT_LEAGUE = "lc"
    CHAT_RAID = "sell"
